@@ -1,6 +1,48 @@
+// Copyright 2019 The Scriptisto Authors
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//      http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+use failure::format_err;
 use log::debug;
+use std::str::FromStr;
 use structopt::StructOpt;
 
+// TODO: figure out how to add to structopt.
+#[derive(Debug, PartialEq)]
+pub enum BuildMode {
+    Default,
+    Source,
+    Full,
+}
+
+impl FromStr for BuildMode {
+    type Err = failure::Error;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        use BuildMode::*;
+        Ok(match s {
+            "" => Default,
+            "source" => Source,
+            "full" => Full,
+            _ => {
+                return Err(format_err!(
+                    "Incorrect SCRIPTISTO_BUILD environment variable value. Available values: <unset>, source, full."
+                ))
+            }
+        })
+    }
+}
+
 #[derive(Debug, StructOpt, PartialEq)]
 #[structopt(
     name = "scriptisto",
@@ -44,7 +86,7 @@ pub fn from_args(args: &[String]) -> Opt {
             display_help();
             unreachable!();
         }
-        Some(ref script_src) if script_src.starts_with(".") || script_src.starts_with("/") => {
+        Some(ref script_src) if script_src.starts_with('.') || script_src.starts_with('/') => {
             // Do not use structopt, because it will try to recognize subcommands in all args.
             let extra_args: Vec<_> = args_iter.cloned().collect();
             Opt {
